@@ -43,6 +43,12 @@ class ConnectionService:
         self.host = HostService()
         self.set_url(str(url))
 
+    @classmethod
+    def microservice_response(cls, reverse_url: str, method: str, **kwargs):
+        url = cls.reverse_url(reverse_url)
+        service = cls(url, **kwargs)
+        return service.service_response(method=method, **kwargs)
+
     def _allowed_methods(self):
         return [m.upper() for m in self.http_method_names if hasattr(self, m)]
 
@@ -154,11 +160,20 @@ class MicroServiceConnect(ConnectionService):
         super().__init__(url, **kwargs)
         self.request = request
 
+    @classmethod
+    def microservice_response(cls, request, reverse_url: str, **kwargs):
+        url = cls.reverse_url(reverse_url)
+        service = cls(request, url, special_headers=kwargs.pop('special_headers', {}))
+        method = kwargs.pop('method', None) or request.method
+        return service.service_response(method=method, **kwargs)
+
     @property
     def headers(self) -> dict:
-        headers = super().headers
-        headers['Accept-Language'] = self.request.headers.get('Accept-Language')
-        headers['Remote-User'] = str(self.request.user.id)
+        headers = {
+            'Accept-Language': self.request.headers.get('Accept-Language'),
+            'Remote-User': str(self.request.user.id),
+        }
+        headers.update(super().headers)
         return headers
 
     def get_cookies(self) -> dict:
